from distutils.core import setup

setup(
    name = "maillib",
    version = "0.1",
    description = "A simplified interface to  Python's email package.",
    author = 'Joseph Kocherhans',
    author_email = 'jkocherhans@gmail.com',
    packages = ['maillib'],
    classifiers = [
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Communications :: Email'
    ]
)
